import * as React from "react";
import { UnstyledButton } from "@snowcoders/react-unstyled-button";
import * as classnames from "classnames";
export class Tabs extends React.Component {
    constructor(props) {
        super(props);
        this.validateOldProps();
        this.state = {
            selectedTabIndex: this.props.defaultTabIndex || this.props.tabIndex || 0
        };
    }
    componentDidUpdate(oldProps) {
        this.validateOldProps(oldProps);
    }
    render() {
        let { isBaseStylesDisabled, className } = this.props;
        className = classnames({ "sci-react-tabs": isBaseStylesDisabled !== true }, className);
        return (React.createElement("div", { className: className },
            this.renderTabs(),
            React.createElement("div", { className: "contents" }, this.props.tabs.map((value, index) => {
                let className = classnames("content", { "visible": index === this.state.selectedTabIndex });
                return (React.createElement("div", { className: className }, value.content));
            }))));
    }
    renderTabs() {
        let tabs = [];
        for (let tabIndex = 0; tabIndex < this.props.tabs.length; tabIndex++) {
            let tab = this.props.tabs[tabIndex];
            let className = classnames("tab-item", { "selected": tabIndex === this.state.selectedTabIndex });
            tabs.push(React.createElement("li", { className: className, key: tabIndex },
                React.createElement(UnstyledButton, { className: "tab-button", onClick: this.getOnTabClick(tabIndex) }, tab.header)));
        }
        return (React.createElement("ul", { className: "tabs" }, tabs));
    }
    getOnTabClick(tabIndex) {
        return () => {
            let propCallback = () => {
                if (this.props.onTabChange != null) {
                    this.props.onTabChange(tabIndex);
                }
            };
            if (this.props.tabIndex == null) {
                // Uncontrolled components maintain their own state
                this.setState({
                    selectedTabIndex: tabIndex
                }, () => {
                    propCallback();
                });
            }
            else {
                // Controlled components have their state maintained
                propCallback();
            }
        };
    }
    validateOldProps(oldProps) {
        if (this.props.defaultTabIndex != null &&
            this.props.tabIndex != null) {
            throw new Error("@snowcoders/react-tabs - component can either be controled (props.tabIndex) or uncontroled (props.defaultTabIndex) but not both");
        }
        if (oldProps != null) {
            if (oldProps.defaultTabIndex != null && this.props.defaultTabIndex == null &&
                oldProps.tabIndex != null && this.props.tabIndex == null) {
                throw new Error("@snowcoders/react-tabs - component cannot switch between uncontrolled and controlled component after mounting");
            }
        }
    }
}
//# sourceMappingURL=component.js.map